@@ -4,7 +4,7 @@ package App::ElasticSearch::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '5.7'; # VERSION
+our $VERSION = '5.8'; # VERSION
 
 our $_OPTIONS_PARSED;
 our %_GLOBALS = ();
@@ -405,8 +405,21 @@ sub es_request {
 
     # Error handling
     if( !$resp->is_success ) {
-        die sprintf "es_request(%s/%s) failed[%d]: %s",
-                    $index, $options->{command}, $resp->code, $resp->message;
+        my $msg;
+        eval {
+            my @causes = ();
+            foreach my $cause ( @{ $resp->content->{error}{root_cause} } ) {
+                push @causes, $cause->{index} ? "$cause->{index}: $cause->{reason}" : $cause->{reason};
+            }
+            $msg = join("\n", map { "\t$_" } @causes);
+            1;
+        } or do {
+            # Default to the message, though it's usually unhelpful
+            $msg = $resp->{message};
+        };
+        die sprintf "es_request(%s/%s) failed[%d]:\n%s",
+                    $index, $options->{command}, $resp->code, $msg;
+
     } elsif( !defined $resp->content || ( !is_ref($resp->content) && !length $resp->content )) {
         output({color=>'yellow',stderr=>1},
             sprintf "es_request(%s/%s) empty response[%d]: %s",
@@ -825,7 +838,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 5.7
+version 5.8
 
 =head1 SYNOPSIS
 
